function X = newton_ls_care(A,B,C,X0)
% X=NEWTON_LS_CARE(A,B,C,X0) solves the CARE C + XA + A'X - XBX = 0
% by means of Newton's method with exact line search
%    A, B, C: matrix coefficients
%    X0: a stabilizing initial approximation
%    X : solution of the CARE
tol = 1e-13;
kmax = 30;
X = X0;
err = 1;
k = 0;
while err > tol && k < kmax
    RX = C + X*A + A'*X - X*B*X;
    H = lyapunov((A-B*X)',-RX);
    V = H*B*H;
    a = trace(RX*RX);
    b = trace(RX*V);
    c = trace(V*V);
    tk = fminbnd(@(t) a*(1-t)^2-2*b*(1-t)*t^2+c*t^4,0,2);
    X = X + tk*H;
    err = abs(tk)*norm(H,1)/norm(X,1);
    k = k + 1;
end
if k == kmax
    disp('Warning: reached the maximum number of iterations')
end
